@@ -144,6 +144,11 @@ def install_npm_packages_if_not_installed():
     if not npm_package.is_installed():
         npm_package.install()
 
+@covfee_cli.command()
+def installjs():
+    _, app = create_app('local')
+    with app.app_context():
+        install_npm_packages_if_not_installed()
 
 @covfee_cli.command()
 @click.option("--force", is_flag=True, help="Specify to overwrite existing databases.")
